@@ -41,7 +41,7 @@ def performance_modelli_regressione(df, lista_colonne_x, colonna_y):
     for reg in regressor:
         scores.append(np.mean(cross_val_score(reg, X, Y, cv=5)))
     #add figure size 
-    plt.figure(figsize=(20,10))
+    plt.figure(figsize=(30,10))
     plt.bar(range(len(regressor)), scores)
     plt.xticks(range(len(regressor)), [reg.__class__.__name__ for reg in regressor])
     plt.ylabel("Media CV Score")
@@ -81,7 +81,7 @@ def performance_modelli_classificazione(df, lista_colonne_x, colonna_y):
     for reg in regressor:
         scores.append(np.mean(cross_val_score(reg, X, Y, cv=5)))
     #add figure size 
-    plt.figure(figsize=(20,10))
+    plt.figure(figsize=(30,10))
     plt.bar(range(len(regressor)), scores)
     plt.xticks(range(len(regressor)), [reg.__class__.__name__ for reg in regressor])
     plt.ylabel("Media CV Score")
@@ -666,7 +666,8 @@ def carica_modello(nome_modello):
     return reg
 
 #make function to Explain Any Machine Learning Model with Shap
-def shap_explainer(reg, df, lista_colonne_x, colonna_y):
+##plot summary of model with shap
+def spiega_modello(reg, df, lista_colonne_x, colonna_y):
     import shap
     import numpy as np
     import pandas as pd
@@ -682,7 +683,4 @@ def shap_explainer(reg, df, lista_colonne_x, colonna_y):
     explainer = shap.TreeExplainer(reg)
     shap_values = explainer.shap_values(X)
     shap.summary_plot(shap_values, X)
-    shap.dependence_plot(Y, shap_values, X)
-
-
-
+    shap.summary_plot(shap_values, X, plot_type='bar')
